#[non_exhaustive]pub enum OverrideReconstruction {
PreserveObservedState,
InferImageOverrides,
}Expand description
Caller-selected treatment of effective values that may originate from image defaults.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
PreserveObservedState
Preserve every supported effective value as an explicit neutral-model value.
InferImageOverrides
Compare effective container values with linked image defaults and retain inferred overrides.