CreationEvidence

Struct CreationEvidence 

pub struct CreationEvidence { /* private fields */ }
Optional runtime creation-command evidence.

Arguments are sensitive by default and never override contradictory effective inspection fields. The evidence can contribute provenance without being present at all.

Implementations

Source

impl CreationEvidence

pub fn new<I, S>(source_id: SourceId, arguments: I) -> Self
where I: IntoIterator<Item = S>, S: Into<String>,

Creates optional evidence with sensitive command arguments.

pub const fn source_id(&self) -> &SourceId

Returns the stable, caller-redacted evidence identity.

pub fn arguments(&self) -> &[ProtectedString]

Returns the protected creation arguments.