RuntimeSnapshot

Struct RuntimeSnapshot 

pub struct RuntimeSnapshot { /* private fields */ }
A complete caller-selected set of related runtime observations.

Implementations

Source

impl RuntimeSnapshot

pub const fn new( application_name: Identifier, implementation: RuntimeImplementation, ) -> Self

Creates an empty snapshot without reading a runtime or ambient state.

pub const fn application_name(&self) -> &Identifier

Returns the neutral application name selected by the caller.

pub const fn implementation(&self) -> &RuntimeImplementation

Returns the runtime implementation that produced this snapshot.

pub fn add_container( &mut self, container: ContainerObservation, ) -> Result<(), RuntimeSnapshotError>

Adds a uniquely identified container observation.

Errors

Returns RuntimeSnapshotError for duplicate source identities or container names.

pub fn containers(&self) -> &[ContainerObservation]

Returns containers in caller-selected discovery order.

pub fn add_image( &mut self, image: ImageObservation, ) -> Result<(), RuntimeSnapshotError>

Adds a uniquely identified image observation.

Errors

Returns RuntimeSnapshotError for a duplicate source identity.

pub fn images(&self) -> &[ImageObservation]

Returns images in caller-selected discovery order.

pub fn add_network( &mut self, network: NetworkObservation, ) -> Result<(), RuntimeSnapshotError>

Adds a uniquely identified and named network observation.

Errors

Returns RuntimeSnapshotError for duplicate source identities or network names.

pub fn networks(&self) -> &[NetworkObservation]

Returns networks in caller-selected discovery order.

pub fn add_volume( &mut self, volume: VolumeObservation, ) -> Result<(), RuntimeSnapshotError>

Adds a uniquely identified and named volume observation.

Errors

Returns RuntimeSnapshotError for duplicate source identities or volume names.

pub fn volumes(&self) -> &[VolumeObservation]

Returns volumes in caller-selected discovery order.

pub fn add_pod( &mut self, pod: PodObservation, ) -> Result<(), RuntimeSnapshotError>

Adds a uniquely identified and named pod observation.

Errors

Returns RuntimeSnapshotError for duplicate source identities or pod names.

pub fn pods(&self) -> &[PodObservation]

Returns pods in caller-selected discovery order.