pub struct CreationEvidence { /* private fields */ }Expand description
Optional runtime creation-command evidence.
Arguments are sensitive by default and never override contradictory effective inspection fields. The evidence can contribute provenance without being present at all.
Implementations
Sourceimpl CreationEvidence
impl CreationEvidence
Sourcepub fn new<I, S>(source_id: SourceId, arguments: I) -> Self
pub fn new<I, S>(source_id: SourceId, arguments: I) -> Self
Creates optional evidence with sensitive command arguments.
Sourcepub const fn source_id(&self) -> &SourceId
pub const fn source_id(&self) -> &SourceId
Returns the stable, caller-redacted evidence identity.
Sourcepub fn arguments(&self) -> &[ProtectedString]
pub fn arguments(&self) -> &[ProtectedString]
Returns the protected creation arguments.