pub struct ImageObservation { /* private fields */ }Expand description
Effective image configuration used to classify container overrides.
Implementations
Sourceimpl ImageObservation
impl ImageObservation
Sourcepub const fn new(source_id: SourceId) -> Self
pub const fn new(source_id: SourceId) -> Self
Creates an image observation with no assumed fields.
Sourcepub fn set_command(&mut self, command: EffectiveCommand)
pub fn set_command(&mut self, command: EffectiveCommand)
Records the image’s effective command default.
Sourcepub const fn command(&self) -> Option<&EffectiveCommand>
pub const fn command(&self) -> Option<&EffectiveCommand>
Returns the observed command default, if the adapter supplied it.
Sourcepub fn set_environment(&mut self, environment: Vec<RuntimeEnvironmentVariable>)
pub fn set_environment(&mut self, environment: Vec<RuntimeEnvironmentVariable>)
Records the complete ordered image environment defaults, including an empty collection.
Sourcepub fn environment(&self) -> Option<&[RuntimeEnvironmentVariable]>
pub fn environment(&self) -> Option<&[RuntimeEnvironmentVariable]>
Returns the observed environment defaults, if the adapter supplied them.
Sourcepub fn set_labels(&mut self, labels: Vec<RuntimeMetadataLabel>)
pub fn set_labels(&mut self, labels: Vec<RuntimeMetadataLabel>)
Records the complete deterministic image metadata-label map, including an empty map.
Sourcepub fn labels(&self) -> Option<&[RuntimeMetadataLabel]>
pub fn labels(&self) -> Option<&[RuntimeMetadataLabel]>
Returns the observed image metadata labels, if the adapter supplied them.
Sourcepub fn set_user(&mut self, user: impl Into<String>)
pub fn set_user(&mut self, user: impl Into<String>)
Records a non-empty image user default as sensitive runtime data.
Sourcepub const fn user(&self) -> Option<&ProtectedString>
pub const fn user(&self) -> Option<&ProtectedString>
Returns the observed image user default.
Sourcepub fn set_working_directory(&mut self, working_directory: impl Into<String>)
pub fn set_working_directory(&mut self, working_directory: impl Into<String>)
Records a non-empty image working-directory default as sensitive runtime data.
Sourcepub const fn working_directory(&self) -> Option<&ProtectedString>
pub const fn working_directory(&self) -> Option<&ProtectedString>
Returns the observed image working-directory default.
Sourcepub fn set_healthcheck(&mut self, healthcheck: RuntimeHealthcheck)
pub fn set_healthcheck(&mut self, healthcheck: RuntimeHealthcheck)
Records the complete effective regular health-check configuration, including its absence.
Sourcepub const fn healthcheck(&self) -> Option<&RuntimeHealthcheck>
pub const fn healthcheck(&self) -> Option<&RuntimeHealthcheck>
Returns the observed regular health-check configuration, if the adapter supplied it.